#!/usr/bin/env python3

from FFDHud import FFDHud, FFDHudMenu
import subprocess
import sys
from functools import partial

def run_command(hud : FFDHud, cmd : [str], shell : bool = False, confirm : bool = False):
	if confirm and not hud.confirm("Execute `" + " ".join(cmd) + "`?"):
		return
	try:
		hud.less(subprocess.check_output(cmd, shell=shell))
	except Exception as e:
		hud.less(str(e))

def main():
	if len(sys.argv) != 2:
		print("should only have one argument of device file name")
		sys.exit(1)
	device_path = "/dev/" + sys.argv[1]
	hud = FFDHud(device_path, idle=30)
	main_menu = FFDHudMenu(hud)

	info_menu = FFDHudMenu(hud, "Info")
	info_menu.add_option("Temperature", partial(run_command, hud, ["sensors"]))
	info_menu.add_option("IPMI Lan", partial(run_command, hud, ["sudo ipmitool lan print | grep --color=never -e 'IP Address' -e 'Subnet Mask' -e 'MAC Address' -e 'Default Gateway IP'"], shell=True))
	info_menu.add_option("lsdev", partial(run_command, hud, ["lsdev", "-n"]))
	info_menu.add_option("Back", info_menu.hide)
	main_menu.add_submenu(info_menu)

	admin_menu = FFDHudMenu(hud, "Administration")
	admin_menu.add_option("dmap", partial(run_command, hud, ["dmap"], confirm=True))
	admin_menu.add_option("dalias", partial(run_command, hud, ["dalias"], confirm=True))
	admin_menu.add_option("Back", admin_menu.hide)
	main_menu.add_submenu(admin_menu)

	power_menu = FFDHudMenu(hud, "Power")
	power_menu.add_option("Shutdown", partial(run_command, hud, ["shutdown", "-h", "now"], confirm=True))
	power_menu.add_option("Reboot", partial(run_command, hud, ["reboot"], confirm=True))
	power_menu.add_option("Back", power_menu.hide)
	main_menu.add_submenu(power_menu)

	main_menu.show()

if __name__ == "__main__":
	main()
